@@ -49,14 +49,14 @@ ctStanFitUpdate <- function(oldfit, data=NA, recompile=FALSE,refit=FALSE,...){
 }
 
 
-T0VARredundancies <- function(ctm) {
+T0VARredundancies <- function(ctm) { #check for redundant T0VAR parameters (because indvarying t0means) and disable
   whichT0VAR_T0MEANSindvarying <- ctm$pars$matrix %in% 'T0VAR'  &  
     is.na(ctm$pars$value) &
     (ctm$pars$row %in% ctm$pars$row[ctm$pars$matrix %in% 'T0MEANS' & ctm$pars$indvarying] |
         ctm$pars$col %in% ctm$pars$row[ctm$pars$matrix %in% 'T0MEANS' & ctm$pars$indvarying])
   if(any(whichT0VAR_T0MEANSindvarying)){
-    message('Free T0VAR parameters as well as indvarying T0MEANS -- fixing T0VAR pars to diag matrix of 1e-3')
-    ctm$pars$value[whichT0VAR_T0MEANSindvarying & ctm$pars$col == ctm$pars$row ] <- 1e-3
+    message('Free T0VAR parameters as well as indvarying T0MEANS -- fixing T0VAR pars to diag matrix of 1e-6')
+    ctm$pars$value[whichT0VAR_T0MEANSindvarying & ctm$pars$col == ctm$pars$row ] <- 1e-6
     ctm$pars$value[whichT0VAR_T0MEANSindvarying & ctm$pars$col != ctm$pars$row ] <- 0
     ctm$pars$param[whichT0VAR_T0MEANSindvarying] <- NA
     ctm$pars$transform[whichT0VAR_T0MEANSindvarying] <- NA
@@ -78,12 +78,12 @@ T0VARredundancies <- function(ctm) {
 
 #' ctStanFit
 #'
-#' Fits a ctsem model specified via \code{\link{ctModel}} with type either 'stanct' or 'standt'.
+#' Fits a ctsem model specified via \code{\link{ctModel}} with type either 'ct' or 'dt'.
 #' 
 #' @param datalong long format data containing columns for subject id (numeric values, 1 to max subjects), manifest variables, 
 #' any time dependent (i.e. varying within subject) predictors, 
 #' and any time independent (not varying within subject) predictors.
-#' @param ctstanmodel model object as generated by \code{\link{ctModel}} with type='stanct' or 'standt', for continuous or discrete time
+#' @param ctstanmodel model object as generated by \code{\link{ctModel}} with type='ct' or 'dt', for continuous or discrete time
 #' models respectively.
 #' @param stanmodeltext already specified Stan model character string, generally leave NA unless modifying Stan model directly.
 #' (Possible after modification of output from fit=FALSE)
@@ -107,7 +107,6 @@ T0VARredundancies <- function(ctm) {
 #' @param nopriors deprecated, use priors argument. logical. If TRUE, any priors are disabled -- sometimes desirable for optimization. 
 #' @param priors if TRUE, priors are included in computations, otherwise specified priors are ignored.
 #' @param iter used when \code{optimize=FALSE}. number of iterations, half of which will be devoted to warmup by default when sampling.
-#' When optimizing, this is the maximum number of iterations to allow -- convergence hopefully occurs before this!
 #' @param inits either character string 'optimize, NULL, or vector of (unconstrained)
 #' parameter start values, as returned by the rstan function \code{rstan::unconstrain_pars}, or the parameter values
 #' found in a ctsem fit object \code{myfit$stanfit$rawest} (or \code{$rawposterior}) for instance. 
@@ -156,7 +155,7 @@ T0VARredundancies <- function(ctm) {
 #' \donttest{
 #' 
 #' #generate a ctStanModel relying heavily on defaults
-#' model<-ctModel(type='stanct',
+#' model<-ctModel(type='ct',
 #'   latentNames=c('eta1','eta2'),
 #'   manifestNames=c('Y1','Y2'),
 #'   MANIFESTVAR=diag(.1,2),
@@ -240,12 +239,12 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' ##simple univariate default model
 #' 
-#' m <- ctModel(type = 'stanct', manifestNames = c('Y1'), LAMBDA = diag(1))
+#' m <- ctModel(type = 'ct', manifestNames = c('Y1'), LAMBDA = diag(1))
 #' ctModelLatex(m)
 #' 
 #' #Specify univariate linear growth curve
 #' 
-#' m1 <- ctModel(type = 'stanct',
+#' m1 <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   DRIFT=matrix(-.0001,nrow=1,ncol=1),
 #'   DIFFUSION=matrix(0,nrow=1,ncol=1),
@@ -275,7 +274,7 @@ T0VARredundancies <- function(ctm) {
 #'  ### Further example models
 #' 
 #' #Include intervention
-#' m2 <- ctModel(type = 'stanct',
+#' m2 <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   n.TDpred=1,TDpredNames = 'TD1', #this line includes the intervention
 #'   TDPREDEFFECT=matrix(c('tdpredeffect'),nrow=1,ncol=1), #intervention effect
@@ -291,7 +290,7 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' 
 #' #Individual differences in intervention, Bayesian estimation, covariates
-#' m2i <- ctModel(type = 'stanct',
+#' m2i <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   TIpredNames = 'age',
 #'   TDpredNames = 'TD1', #this line includes the intervention
@@ -307,7 +306,7 @@ T0VARredundancies <- function(ctm) {
 #'   
 #'   
 #' #Including covariate effects
-#' m2ic <- ctModel(type = 'stanct',
+#' m2ic <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   n.TIpred = 1, TIpredNames = 'age',
 #'   n.TDpred=1,TDpredNames = 'TD1', #this line includes the intervention
@@ -325,7 +324,7 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' 
 #' #Include deterministic dynamics
-#' m3 <- ctModel(type = 'stanct',
+#' m3 <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   n.TDpred=1,TDpredNames = 'TD1', #this line includes the intervention
 #'   TDPREDEFFECT=matrix(c('tdpredeffect'),nrow=1,ncol=1), #intervention effect
@@ -343,7 +342,7 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' 
 #' #Add system noise to allow for fluctuations that persist in time
-#' m3n <- ctModel(type = 'stanct',
+#' m3n <- ctModel(type = 'ct',
 #'   manifestNames = c('Y1'), latentNames=c('eta1'),
 #'   n.TDpred=1,TDpredNames = 'TD1', #this line includes the intervention
 #'   TDPREDEFFECT=matrix(c('tdpredeffect'),nrow=1,ncol=1), #intervention effect
@@ -360,7 +359,7 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' #include 2nd latent process
 #' 
-#' m4 <- ctModel(n.manifest = 2,n.latent = 2, type = 'stanct',
+#' m4 <- ctModel(n.manifest = 2,n.latent = 2, type = 'ct',
 #'   manifestNames = c('Y1','Y2'), latentNames=c('L1','L2'),
 #'   n.TDpred=1,TDpredNames = 'TD1',
 #'   TDPREDEFFECT=matrix(c('tdpredeffect1','tdpredeffect2'),nrow=2,ncol=1),
@@ -375,7 +374,7 @@ T0VARredundancies <- function(ctm) {
 #' 
 #' #dynamic factor model -- fixing CINT to 0 and freeing indicator level intercepts
 #' 
-#' m3df <- ctModel(type = 'stanct',
+#' m3df <- ctModel(type = 'ct',
 #'   manifestNames = c('Y2','Y3'), latentNames=c('eta1'),
 #'   n.TDpred=1,TDpredNames = 'TD1', #this line includes the intervention
 #'   TDPREDEFFECT=matrix(c('tdpredeffect'),nrow=1,ncol=1), #intervention effect
@@ -410,7 +409,7 @@ ctStanFit<-function(datalong, ctstanmodel, stanmodeltext=NA, iter=1000, intovers
   if(any(!is.na(derrind))) warning('derrind argment is deprecated, computed automatically now')
   
   datalong <- data.frame(datalong)
-
+  
   if(!ctstanmodel$timeName %in% colnames(datalong) && !ctstanmodel$continuoustime) {
     dtable <- data.table(datalong)
     dtable[,.ObsCount:=1:.N,by=ctstanmodel$id]
@@ -461,18 +460,19 @@ ctStanFit<-function(datalong, ctstanmodel, stanmodeltext=NA, iter=1000, intovers
   }
   
   #collect individual stationary elements and update ctm$pars
-  if(any(ctm$pars$param %in% 'stationary')) stop('Stationary option temporarily unavailable -- reductions needed to pass all CRAN checks')
-  ctm$t0varstationary <- as.matrix(rbind(ctm$pars[which(ctm$pars$param %in% 'stationary' & ctm$pars$matrix %in% 'T0VAR'),c('row','col')]))
-  if(nrow(ctm$t0varstationary) > 0){ #ensure upper tri is consistent with lower
-    for(i in 1:nrow(ctm$t0varstationary)){
-      if(ctm$t0varstationary[i,1] != ctm$t0varstationary[i,2]) ctm$t0varstationary <- rbind(ctm$t0varstationary,ctm$t0varstationary[i,c(2,1)])
-    }}
-  ctm$t0varstationary = unique(ctm$t0varstationary) #remove any duplicated rows
-  ctm$t0meansstationary <- as.matrix(rbind(ctm$pars[which(ctm$pars$param[ctm$pars$matrix %in% 'T0MEANS'] %in% 'stationary'),c('row','col')]))
-  ctm$pars$value[ctm$pars$param %in% 'stationary'] <- -99 #does this get inserted?
-  ctm$pars$indvarying[ctm$pars$param %in% 'stationary'] <- FALSE
-  ctm$pars$transform[ctm$pars$param %in% 'stationary'] <- NA
-  ctm$pars$param[ctm$pars$param %in% 'stationary'] <- NA
+  if(any(ctm$pars$param %in% 'stationary'))  stop('Stationary option temporarily unavailable -- reductions needed to pass all CRAN checks')
+    ctm$t0varstationary <- as.matrix(rbind(ctm$pars[which(ctm$pars$param %in% 'stationary' & ctm$pars$matrix %in% 'T0VAR'),c('row','col')]))
+    if(nrow(ctm$t0varstationary) > 0){ #ensure upper tri is consistent with lower
+      for(i in 1:nrow(ctm$t0varstationary)){
+        if(ctm$t0varstationary[i,1] != ctm$t0varstationary[i,2]) ctm$t0varstationary <- rbind(ctm$t0varstationary,ctm$t0varstationary[i,c(2,1)])
+      }}
+    ctm$t0varstationary = unique(ctm$t0varstationary) #remove any duplicated rows
+    ctm$t0meansstationary <- as.matrix(rbind(ctm$pars[which(ctm$pars$param[ctm$pars$matrix %in% 'T0MEANS'] %in% 'stationary'),c('row','col')]))
+    ctm$pars$value[ctm$pars$param %in% 'stationary'] <- -99 #does this get inserted?
+    ctm$pars$indvarying[ctm$pars$param %in% 'stationary'] <- FALSE
+    ctm$pars$transform[ctm$pars$param %in% 'stationary'] <- NA
+    ctm$pars$param[ctm$pars$param %in% 'stationary'] <- NA
+  
   
   if(length(unique(datalong[,ctm$subjectIDname]))==1 && any(ctm$pars$indvarying[is.na(ctm$pars$value)]==TRUE)){
     # is.null(ctm$fixedrawpopmeans) && is.null(ctm$fixedsubpars) & is.null(ctm$forcemultisubject)) {
@@ -484,12 +484,12 @@ ctStanFit<-function(datalong, ctstanmodel, stanmodeltext=NA, iter=1000, intovers
     # is.null(ctm$fixedrawpopmeans) & is.null(ctm$fixedsubpars) & is.null(ctm$forcemultisubject)) {
     for(ri in 1:nrow(ctm$pars)){
       if(is.na(ctm$pars$value[ri]) && ctm$pars$matrix[ri] %in% 'T0VAR'){
-        ctm$pars$value[ri] <- ifelse(ctm$pars$row[ri] == ctm$pars$col[ri], 1, 0)
+        ctm$pars$value[ri] <- ifelse(ctm$pars$row[ri] == ctm$pars$col[ri], 1e-3, 0)
       }
     }
-    message('Free T0VAR parameters fixed to diagonal matrix of 1 as only 1 subject - consider appropriateness!')
+    message('Free T0VAR parameters fixed to diagonal matrix of 0.001 as only 1 subject - consider appropriateness!')
   }
-
+  
   if(binomial){
     message('Binomial argument deprecated -- in future set manifesttype in the model object to 1 for binary indicators')
     intoverstates <- FALSE
@@ -516,22 +516,21 @@ ctStanFit<-function(datalong, ctstanmodel, stanmodeltext=NA, iter=1000, intovers
   #   # message('No individual variation -- disabling intoverpop switch'); 
   #   intoverpop <- FALSE
   # }
-  
-  
+
   ctm <- ctModel0DRIFT(ctm, ctm$continuoustime) #offset 0 drift
   ctm$pars <- ctModelStatesAndPARS(ctm$pars,statenames = ctm$latentNames,tdprednames=ctm$TDpredNames) #replace latent states and PARS with state and PAR[] refs, need this early because we rely on [] detection
   if(intoverpop)   ctm <- ctStanModelIntOverPop(ctm) #extend system matrices for individual differences
   
-  #check this *after* replacing PARS references as needed
-  if(any(duplicated(ctm$pars$param[ctm$pars$matrix %in% 'T0MEANS' & 
-      !grepl('[',ctm$pars$param,fixed=TRUE) &
-      !is.na(ctm$pars$param)]))) stop(paste0(
-        'Unfortunately, duplicate T0MEANS parameters must be specified via inclusion of additional PARS matrix in ctModel: e.g.,
-ctModel(... #regular model code
-PARS=c("t0mPar||TRUE"), #specify an additional parameter called t0mPar, with random effects
-T0MEANS=c("t0mPar","t0mPar"), #insert this parameter into the T0MEANS matrix as many times as needed.
-... #regular model code)
-'))
+#   #check this *after* replacing PARS references as needed
+#   if(any(duplicated(ctm$pars$param[ctm$pars$matrix %in% 'T0MEANS' &
+#       !grepl('[',ctm$pars$param,fixed=TRUE) &
+#       !is.na(ctm$pars$param)]))) stop(paste0(
+#         'Unfortunately, duplicate T0MEANS parameters must be specified via inclusion of additional PARS matrix in ctModel: e.g.,
+# ctModel(... #regular model code
+# PARS=c("t0mPar||TRUE"), #specify an additional parameter called t0mPar, with random effects
+# T0MEANS=c("t0mPar","t0mPar"), #insert this parameter into the T0MEANS matrix as many times as needed.
+# ... #regular model code)
+# '))
   
   #jacobian addition
   ctm$jacobian <- try(ctJacobian(ctm))
@@ -692,8 +691,8 @@ install.packages("rstan", repos = c("https://mc-stan.org/r-packages/", getOption
       if(!gendata) sm <- stanmodels$ctsm else sm <- stanmodels$ctsmgen
     }
     
-
-# configure inits ---------------------------------------------------------
+    
+    # configure inits ---------------------------------------------------------
     initOptim <- (length(inits)==1 && (inits=='optimize' || inits=='Optimize' || inits=='optimise' || inits=='Optimise'))
     if(optimize || initOptim){ #then set optimcontrol list
       optimcontrol$cores <- cores
@@ -705,7 +704,7 @@ install.packages("rstan", repos = c("https://mc-stan.org/r-packages/", getOption
       optimcontrol$plot=plot
       optimcontrol$matsetup <- data.frame(ctm$modelmats$matsetup)
     }
-
+    
     if(!optimize && !is.null(inits)){
       if('list' %in% class(inits)){
         staninits=inits
@@ -717,16 +716,16 @@ install.packages("rstan", repos = c("https://mc-stan.org/r-packages/", getOption
           if(!intoverpop & ! intoverstates) stop('Cannot initialize with optimization unless intoverpop and intoverstates are set to TRUE')
           inits <- do.call(stanoptimis,optimcontrol)$rawest
         }
-      sf <- stan_reinitsf(sm,standata)
-      staninits <- list() 
-      if(chains > 1){ #set all chains to same inits
-        for(i in 1:chains){
-          staninits[[i]]<-constrain_pars(sf,inits+rnorm(length(inits),0,.01))
+        sf <- stan_reinitsf(sm,standata)
+        staninits <- list() 
+        if(chains > 1){ #set all chains to same inits
+          for(i in 1:chains){
+            staninits[[i]]<-constrain_pars(sf,inits+rnorm(length(inits),0,.01))
+          }
         }
       }
-      }
-  }
-
+    }
+    
     
     if(!optimize){
       
