@@ -4,8 +4,9 @@ library(devtools)
   context("allexamples")
   
   test_that("allexamples1", {
-    if (file.exists('../../ctsem/')) 
-      run_examples(pkg = '../../ctsem/.',test=TRUE) else run_examples(pkg = '../../.',test=TRUE)
+    # if (file.exists('../../ctsem/')) 
+      run_examples(pkg = '../../ctsem/.',run_donttest = TRUE, run_dontrun = TRUE) 
+    # else run_examples(pkg = '../../.',test=TRUE)
   })
   }
 }
