@@ -34,7 +34,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     tdat[2,'Y1'] <- NA
     tdat[tdat[,'id']==2,'TI1'] <- NA
     
-    checkm<-suppressMessages(ctModel(type='stanct',Tpoints=Tpoints,
+    checkm<-suppressMessages(ctModel(type='ct',Tpoints=Tpoints,
       MANIFESTVAR=diag(0.5,1),
       DRIFT=matrix(c(-.3),nrow=1),
       DIFFUSION=matrix(c(2),1),
@@ -48,26 +48,26 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     
     checkm$pars[c(-1,-7) ,c('TI1_effect')] <- FALSE
     
-    tfit1<-ctStanFit(tdat,checkm,cores=2,optimize=TRUE,
-      optimcontrol=list(is=TRUE,finishsamples=500),
+    tfit1<-ctStanFit(tdat,checkm,optimize=TRUE,
+      optimcontrol=list(is=TRUE,carefulfit=F),
       priors=TRUE,verbose=0)
     s1=summary(tfit1)
     
     test_isclose(s1$tipreds[2,'mean'],5,tol=.2)
-    test_isclose(s1$popsd[2,'mean'],.6,tol=.2)
+    test_isclose(s1$popsd[2,'50%'],.6,tol=.2)
     
     tfit2<-ctStanFit(tdat,checkm,optimize=TRUE,cores=2,verbose=0,
       optimcontrol=list(is=FALSE),priors=TRUE)
     s2=summary(tfit2)
     
     test_isclose(s2$tipreds[2,'mean'],5,tol=.2)
-    test_isclose(s2$popsd[2,'mean'],.6,tol=.2)
+    test_isclose(s2$popsd[2,'50%'],.6,tol=.2)
     
     tfit3<-suppressWarnings(ctStanFit(tdat,checkm,iter=300,chains=2,optimize=FALSE,
       control=list(adapt_delta=.8,max_treedepth=6),plot=FALSE))
     s3=summary(tfit3)
     
-    test_isclose(s3$tipreds[2,'mean'],5,tol=.2)
-    test_isclose(s3$popsd[2,'mean'],.6,tol=.2)
+    test_isclose(s3$tipreds[2,'mean'],5,tol=.5)
+    test_isclose(s3$popsd[2,'50%'],.6,tol=.5)
   })
 }
